pub struct CredentialRegistry { /* private fields */ }Expand description
Validated references plus provider implementations, without serialized secret values.
Implementations
Sourceimpl CredentialRegistry
impl CredentialRegistry
pub fn new(declarations: Vec<CredentialConfig>) -> Result<Self, CredentialError>
Sourcepub fn register_provider(
&mut self,
name: String,
provider: Arc<dyn CredentialProvider>,
) -> Result<(), CredentialError>
pub fn register_provider( &mut self, name: String, provider: Arc<dyn CredentialProvider>, ) -> Result<(), CredentialError>
Registration cannot replace an existing provider, including the built-in env adapter.
pub fn kind(&self, name: &str) -> Result<CredentialKind, CredentialError>
pub fn cache_lifetime( &self, name: &str, ) -> Result<CredentialCacheLifetime, CredentialError>
pub fn resolve(&self, name: &str) -> Result<CredentialMaterial, CredentialError>
pub fn update( &self, name: &str, material: Vec<u8>, ) -> Result<(), CredentialError>