note_embedding_text

Function note_embedding_text 

pub fn note_embedding_text(note: &Note) -> String
Build the canonical text embedded for a note when no explicit bounded embedding prefix was supplied at creation time.