track_background_task

Function track_background_task 

pub fn track_background_task<F>(fut: F)
where F: Future<Output = ()> + Send + 'static,
Spawn a fire-and-forget task through spawn_tracked_task.

Callers that need a boot or shutdown barrier should retain and await the returned handle from spawn_tracked_task instead of detaching it here.