Module entity_write

Module entity_write 

Entity revision preconditions, evaluated by the shared writer transaction.

Structs

EntityVersionConflict
A caller’s entity revision did not match the live writer-transaction row.