pub struct MissingPackDependencies {
pub missing: Vec<MissingPackDependency>,
}Expand description
Multiple missing pack dependencies collected into one error (ADR-037).
Fields
missing: Vec<MissingPackDependency>Trait Implementations
Sourceimpl Clone for MissingPackDependencies
impl Clone for MissingPackDependencies
Sourcefn clone(&self) -> MissingPackDependencies
fn clone(&self) -> MissingPackDependencies
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissingPackDependencies
impl Debug for MissingPackDependencies
Sourceimpl Display for MissingPackDependencies
impl Display for MissingPackDependencies
Sourceimpl Error for MissingPackDependencies
impl Error for MissingPackDependencies
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for MissingPackDependencies
impl PartialEq for MissingPackDependencies
Sourcefn eq(&self, other: &MissingPackDependencies) -> bool
fn eq(&self, other: &MissingPackDependencies) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MissingPackDependencies
impl StructuralPartialEq for MissingPackDependencies