pub enum WireWriterTaskFailure {
RequestFailed {
request_state: WireWriterTaskState,
},
TaskTerminated {
request_state: WireWriterTaskState,
},
}Expand description
Whether a writer-state error belongs to one failed request on a still-live seam or to a permanently retired writer task.
Variants
RequestFailed
Fields

request_state: WireWriterTaskStateTaskTerminated
Fields

request_state: WireWriterTaskStateTrait Implementations
Sourceimpl Clone for WireWriterTaskFailure
impl Clone for WireWriterTaskFailure
impl Copy for WireWriterTaskFailure
Sourceimpl Debug for WireWriterTaskFailure
impl Debug for WireWriterTaskFailure
Sourceimpl<'de> Deserialize<'de> for WireWriterTaskFailure
impl<'de> Deserialize<'de> for WireWriterTaskFailure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WireWriterTaskFailure
Sourceimpl PartialEq for WireWriterTaskFailure
impl PartialEq for WireWriterTaskFailure
Sourceimpl Serialize for WireWriterTaskFailure
impl Serialize for WireWriterTaskFailure
impl StructuralPartialEq for WireWriterTaskFailure