pub async fn scope<F>(ctx: UsageContext, fut: F) -> <F as Future>::Outputwhere
F: Future,Expand description
Run fut with ctx armed as the current dispatch-accounting context.
pub async fn scope<F>(ctx: UsageContext, fut: F) -> <F as Future>::Outputwhere
F: Future,Run fut with ctx armed as the current dispatch-accounting context.