pub async fn apply_post_commit_effects_with_failures(
runtime: &KhiveRuntime,
token: &NamespaceToken,
effects: CommittedPostCommitEffects,
) -> PostCommitEffectsReportExpand description
Failure-preserving form of super::apply_post_commit_effects_with_report.
Runs every effect, collecting the outcomes of those that completed and the
error of each that did not, instead of replacing the outcomes with the
first failure.